@@ -495,7 +495,7 @@ if [ ! -f "$CONFIG_FILE" ]; then
         "max_retries": 10,
         "max_iterations": 40,
         "tool_ignore": ["read_file"],
-        "guide_file": "TUNACODE.md",
+        "guide_file": "AGENTS.md",
         "fallback_response": true,
         "fallback_verbosity": "normal",
         "context_window_size": 200000,
