@@ -20,7 +20,6 @@ from .system import (
     StreamingCommand,
     UpdateCommand,
 )
-from .todo import TodoCommand
 
 __all__ = [
     # System commands
@@ -44,6 +43,4 @@ __all__ = [
     "ModelCommand",
     # Conversation commands
     "CompactCommand",
-    # Todo commands
-    "TodoCommand",
 ]
