@@ -6,6 +6,7 @@ Error recovery utilities for the REPL.
 
 import logging
 
+import tunacode.core.agents as agent_api
 from tunacode.types import StateManager
 from tunacode.ui import console as ui
 
@@ -64,7 +65,8 @@ async def attempt_json_args_recovery(e: Exception, state_manager: StateManager)
 
                             await ui.warning(f"Warning: {MSG_JSON_ARGS_RECOVERY}")
                             logger.info(
-                                f"Successfully recovered tool {part.tool_name} with split JSON args",
+                                f"Successfully recovered tool {part.tool_name} with "
+                                f"split JSON args",
                                 extra={
                                     "original_args": part.args,
                                     "recovered_args": json_objects[0],
@@ -78,7 +80,8 @@ async def attempt_json_args_recovery(e: Exception, state_manager: StateManager)
 
             except Exception as recovery_exc:
                 logger.error(
-                    f"Error during JSON args recovery for tool {getattr(part, 'tool_name', 'unknown')}",
+                    f"Error during JSON args recovery for tool "
+                    f"{getattr(part, 'tool_name', 'unknown')}",
                     exc_info=True,
                     extra={"recovery_exception": str(recovery_exc)},
                 )
@@ -126,17 +129,17 @@ async def attempt_tool_recovery(e: Exception, state_manager: StateManager) -> bo
             },
         )
         await ui.muted(
-            f"⚠️ Model response error. Attempting to recover by parsing tools from text: {str(e)[:100]}..."
+            f"⚠️ Model response error. Attempting to recover by parsing tools "
+            f"from text: {str(e)[:100]}..."
         )
 
         try:
-            from tunacode.core.agents.main import extract_and_execute_tool_calls
 
             def tool_callback_with_state(tool_part, _node):
                 return tool_handler(tool_part, state_manager)
 
             # This function now returns the number of tools found
-            tools_found = await extract_and_execute_tool_calls(
+            tools_found = await agent_api.extract_and_execute_tool_calls(
                 content_to_parse, tool_callback_with_state, state_manager
             )
 
