@@ -30,19 +30,10 @@ async def display_agent_output(res, enable_streaming: bool, state_manager=None)
     if '"tool_uses"' in output:
         return
 
-    # In plan mode, don't display any agent text output at all
-    # The plan will be displayed via the present_plan tool
-    if state_manager and state_manager.is_plan_mode():
-        return
-
-    # Filter out plan mode system prompts and tool definitions
+    # Filter out system prompts and tool definitions
     if any(
         phrase in output
         for phrase in [
-            "PLAN MODE - TOOL EXECUTION ONLY",
-            "🔧 PLAN MODE",
-            "TOOL EXECUTION ONLY 🔧",
-            "planning assistant that ONLY communicates",
             "namespace functions {",
             "namespace multi_tool_use {",
             "You are trained on data up to",
