@@ -9,7 +9,7 @@ from asyncio.exceptions import CancelledError
 
 from prompt_toolkit.application import run_in_terminal
 
-from tunacode.core.agents.main import patch_tool_messages
+from tunacode.core.agents import patch_tool_messages
 from tunacode.core.tool_handler import ToolHandler
 from tunacode.exceptions import UserAbortError
 from tunacode.types import StateManager
@@ -59,18 +59,6 @@ async def tool_handler(part, state_manager: StateManager):
         args = parse_args(part.args)
 
         def confirm_func():
-            # Check if tool is blocked in plan mode first
-            if tool_handler_instance.is_tool_blocked_in_plan_mode(part.tool_name):
-                from tunacode.constants import READ_ONLY_TOOLS
-
-                error_msg = (
-                    f"🔍 Plan Mode: Tool '{part.tool_name}' is not available in Plan Mode.\n"
-                    f"Only read-only tools are allowed: {', '.join(READ_ONLY_TOOLS)}\n"
-                    f"Use 'exit_plan_mode' tool to present your plan and exit Plan Mode."
-                )
-                print(f"\n❌ {error_msg}\n")
-                return True  # Abort the tool
-
             if not tool_handler_instance.should_confirm(part.tool_name):
                 return False
             request = tool_handler_instance.create_confirmation_request(part.tool_name, args)
