@@ -29,8 +29,8 @@ class ApplicationSettings:
             ToolName.GREP,
             ToolName.LIST_DIR,
             ToolName.READ_FILE,
+            ToolName.RESEARCH_CODEBASE,
             ToolName.RUN_COMMAND,
-            ToolName.TODO,
             ToolName.UPDATE_FILE,
             ToolName.WRITE_FILE,
         ]
