@@ -9,12 +9,12 @@ from enum import Enum
 
 # Application info
 APP_NAME = "TunaCode"
-APP_VERSION = "0.0.75"
+APP_VERSION = "0.0.78.11"
 
 
 # File patterns
 GUIDE_FILE_PATTERN = "{name}.md"
-GUIDE_FILE_NAME = "TUNACODE.md"
+GUIDE_FILE_NAME = "AGENTS.md"
 ENV_FILE = ".env"
 CONFIG_FILE_NAME = "tunacode.json"
 
@@ -43,8 +43,8 @@ class ToolName(str, Enum):
     GREP = "grep"
     LIST_DIR = "list_dir"
     GLOB = "glob"
-    TODO = "todo"
-    EXIT_PLAN_MODE = "exit_plan_mode"
+    REACT = "react"
+    RESEARCH_CODEBASE = "research_codebase"
 
 
 # Tool names (backward compatibility)
@@ -56,8 +56,8 @@ TOOL_BASH = ToolName.BASH
 TOOL_GREP = ToolName.GREP
 TOOL_LIST_DIR = ToolName.LIST_DIR
 TOOL_GLOB = ToolName.GLOB
-TOOL_TODO = ToolName.TODO
-TOOL_EXIT_PLAN_MODE = ToolName.EXIT_PLAN_MODE
+TOOL_REACT = ToolName.REACT
+TOOL_RESEARCH_CODEBASE = ToolName.RESEARCH_CODEBASE
 
 # Tool categorization
 READ_ONLY_TOOLS = [
@@ -65,7 +65,8 @@ READ_ONLY_TOOLS = [
     ToolName.GREP,
     ToolName.LIST_DIR,
     ToolName.GLOB,
-    ToolName.EXIT_PLAN_MODE,
+    ToolName.REACT,
+    ToolName.RESEARCH_CODEBASE,
 ]
 WRITE_TOOLS = [ToolName.WRITE_FILE, ToolName.UPDATE_FILE]
 EXECUTE_TOOLS = [ToolName.BASH, ToolName.RUN_COMMAND]
@@ -105,22 +106,31 @@ TUNACODE_HOME_DIR = ".tunacode"
 SESSIONS_SUBDIR = "sessions"
 DEVICE_ID_FILE = "device_id"
 
-# UI colors - Modern sleek color scheme
+# UI colors - Professional monochromatic cyan scheme
 UI_COLORS = {
-    "primary": "#00d7ff",  # Bright cyan
-    "secondary": "#64748b",  # Slate gray
-    "accent": "#7c3aed",  # Purple accent
-    "success": "#22c55e",  # Modern green
-    "warning": "#f59e0b",  # Amber
-    "error": "#ef4444",  # Red
-    "muted": "#94a3b8",  # Light slate
-    "file_ref": "#00d7ff",  # Bright cyan
-    "background": "#0f172a",  # Dark slate
-    "border": "#475569",  # Stronger slate border
+    # Core brand colors
+    "primary": "#00d7ff",  # Bright cyan (primary accent)
+    "primary_light": "#4de4ff",  # Light cyan for hover states
+    "primary_dark": "#0095b3",  # Dark cyan for interactive elements
+    "accent": "#0ea5e9",  # Rich cyan (replaces purple)
+    # Background & structure (cyan-tinted grays)
+    "background": "#0d1720",  # Ultra dark with cyan undertone
+    "surface": "#162332",  # Panels, cards
+    "border": "#2d4461",  # Stronger cyan-gray borders
+    "border_light": "#1e2d3f",  # Subtle borders
+    # Text & content (cyan-tinted neutrals)
+    "muted": "#6b8aa3",  # Secondary text, descriptions
+    "secondary": "#4a6582",  # Tertiary text, less important
+    # Semantic colors (professional, muted)
+    "success": "#059669",  # Corporate emerald green
+    "warning": "#d97706",  # Muted amber
+    "error": "#dc2626",  # Clean red
+    # Legacy compatibility
+    "file_ref": "#00d7ff",  # Same as primary
 }
 
 # UI text and formatting
-UI_PROMPT_PREFIX = "> "
+UI_PROMPT_PREFIX = '<style fg="#00d7ff"><b>> </b></style>'
 UI_THINKING_MESSAGE = "[bold #00d7ff]Thinking...[/bold #00d7ff]"
 UI_DARKGREY_OPEN = "<darkgrey>"
 UI_DARKGREY_CLOSE = "</darkgrey>"
@@ -167,40 +177,6 @@ MSG_UPDATE_INSTRUCTION = "Exit, and run: [bold]pip install --upgrade tunacode-cl
 MSG_VERSION_DISPLAY = "TunaCode CLI {version}"
 MSG_FILE_SIZE_LIMIT = " Please specify a smaller file or use other tools to process it."
 
-
-class TodoStatus(str, Enum):
-    """Enumeration of todo statuses."""
-
-    PENDING = "pending"
-    IN_PROGRESS = "in_progress"
-    COMPLETED = "completed"
-
-
-class TodoPriority(str, Enum):
-    """Enumeration of todo priorities."""
-
-    HIGH = "high"
-    MEDIUM = "medium"
-    LOW = "low"
-
-
-# Todo-related constants (backward compatibility)
-TODO_STATUS_PENDING = TodoStatus.PENDING
-TODO_STATUS_IN_PROGRESS = TodoStatus.IN_PROGRESS
-TODO_STATUS_COMPLETED = TodoStatus.COMPLETED
-TODO_STATUSES = [TodoStatus.PENDING, TodoStatus.IN_PROGRESS, TodoStatus.COMPLETED]
-
-TODO_PRIORITY_HIGH = TodoPriority.HIGH
-TODO_PRIORITY_MEDIUM = TodoPriority.MEDIUM
-TODO_PRIORITY_LOW = TodoPriority.LOW
-TODO_PRIORITIES = [TodoPriority.HIGH, TodoPriority.MEDIUM, TodoPriority.LOW]
-
-# Maximum number of todos allowed per session
-MAX_TODOS_PER_SESSION = 100
-
-# Maximum length for todo content
-MAX_TODO_CONTENT_LENGTH = 500
-
 # JSON parsing retry configuration
 JSON_PARSE_MAX_RETRIES = 10
 JSON_PARSE_BASE_DELAY = 0.1  # Initial delay in seconds
