@@ -72,6 +72,50 @@ def get_tool_description(tool_name: str, tool_args: dict[str, Any]) -> str:
     return tool_desc
 
 
+def get_readable_tool_description(tool_name: str, tool_args: dict[str, Any]) -> str:
+    """Get a human-readable description of a tool operation for batch panel display."""
+    if not isinstance(tool_args, dict):
+        return f"Executing `{tool_name}`"
+
+    if tool_name == "read_file":
+        file_path = tool_args.get("file_path", tool_args.get("filepath", ""))
+        if file_path:
+            return f"Reading `{file_path}`"
+        return "Reading file"
+
+    if tool_name == "list_dir":
+        directory = tool_args.get("directory", "")
+        if directory:
+            return f"Listing directory `{directory}`"
+        return "Listing directory"
+
+    if tool_name == "grep":
+        pattern = tool_args.get("pattern", "")
+        include_files = tool_args.get("include_files", "")
+        if pattern and include_files:
+            return f"Searching for `{pattern}` in `{include_files}`"
+        if pattern:
+            return f"Searching for `{pattern}`"
+        return "Searching files"
+
+    if tool_name == "glob":
+        pattern = tool_args.get("pattern", "")
+        if pattern:
+            return f"Finding files matching `{pattern}`"
+        return "Finding files"
+
+    if tool_name == "research_codebase":
+        query = tool_args.get("query", "")
+        if query:
+            # Truncate long queries for display
+            query_display = query[:60] + "..." if len(query) > 60 else query
+            return f"Researching: {query_display}"
+        return "Researching codebase"
+
+    # Fallback for unknown tools
+    return f"Executing `{tool_name}`"
+
+
 def get_recent_tools_context(tool_calls: list[dict[str, Any]], limit: int = 3) -> str:
     """Get a context string describing recent tool usage."""
     if not tool_calls:
@@ -97,7 +141,8 @@ def create_empty_response_message(
     """Create a constructive message for handling empty responses."""
     tools_context = get_recent_tools_context(tool_calls)
 
-    content = f"""Response appears {empty_reason if empty_reason != "empty" else "empty"} or incomplete. Let's troubleshoot and try again.
+    reason = empty_reason if empty_reason != "empty" else "empty"
+    content = f"""Response appears {reason} or incomplete. Let's troubleshoot and try again.
 
 Task: {message[:200]}...
 {tools_context}
@@ -201,6 +246,34 @@ def create_fallback_response(
     return fallback
 
 
+async def handle_empty_response(
+    message: str,
+    reason: str,
+    iter_index: int,
+    state: Any,
+) -> None:
+    """Handle empty responses by creating a synthetic user message with retry guidance."""
+    from tunacode.ui import console as ui
+
+    force_action_content = create_empty_response_message(
+        message,
+        reason,
+        getattr(state.sm.session, "tool_calls", []),
+        iter_index,
+        state.sm,
+    )
+    create_user_message(force_action_content, state.sm)
+
+    if state.show_thoughts:
+        await ui.warning("\nEMPTY RESPONSE FAILURE - AGGRESSIVE RETRY TRIGGERED")
+        await ui.muted(f"   Reason: {reason}")
+        await ui.muted(
+            f"   Recent tools: "
+            f"{get_recent_tools_context(getattr(state.sm.session, 'tool_calls', []))}"
+        )
+        await ui.muted("   Injecting retry guidance prompt")
+
+
 def format_fallback_output(fallback: FallbackResponse) -> str:
     """Format a fallback response into a comprehensive output string."""
     output_parts = [fallback.summary, ""]
