@@ -3,10 +3,13 @@
 import json
 from typing import Any, Awaitable, Callable, Optional, Tuple
 
+from tunacode.constants import UI_COLORS
 from tunacode.core.logging.logger import get_logger
 from tunacode.core.state import StateManager
+from tunacode.exceptions import UserAbortError
 from tunacode.types import AgentState, UsageTrackerProtocol
 from tunacode.ui.tool_descriptions import get_batch_description, get_tool_description
+from tunacode.utils.file_utils import DotDict
 
 from .response_state import ResponseState
 from .task_completion import check_task_completion
@@ -14,17 +17,7 @@ from .tool_buffer import ToolBuffer
 from .truncation_checker import check_for_truncation
 
 logger = get_logger(__name__)
-
-# Import streaming types with fallback for older versions
-try:
-    from pydantic_ai.messages import PartDeltaEvent, TextPartDelta
-
-    STREAMING_AVAILABLE = True
-except ImportError:
-    # Fallback for older pydantic-ai versions
-    PartDeltaEvent = None
-    TextPartDelta = None
-    STREAMING_AVAILABLE = False
+colors = DotDict(UI_COLORS)
 
 
 async def _process_node(
@@ -39,8 +32,9 @@ async def _process_node(
     """Process a single node from the agent response.
 
     Returns:
-        tuple: (is_empty: bool, reason: Optional[str]) - True if empty/problematic response detected,
-               with reason being one of: "empty", "truncated", "intention_without_action"
+        tuple: (is_empty: bool, reason: Optional[str]) - True if empty/problematic
+               response detected, with reason being one of: "empty", "truncated",
+               "intention_without_action"
     """
     from tunacode.ui import console as ui
 
@@ -99,15 +93,22 @@ async def _process_node(
                             # Agent is trying to complete with pending tools!
                             if state_manager.session.show_thoughts:
                                 await ui.warning(
-                                    "⚠️ PREMATURE COMPLETION DETECTED - Agent queued tools but marked complete"
+                                    "⚠️ PREMATURE COMPLETION DETECTED - "
+                                    "Agent queued tools but marked complete"
                                 )
                                 await ui.muted("   Overriding completion to allow tool execution")
                             # Don't mark as complete - let the tools run first
                             # Update the content to remove the marker but don't set task_completed
                             part.content = cleaned_content
                             # Log this as an issue
+                            pending_tools_count = sum(
+                                1
+                                for p in node.model_response.parts
+                                if getattr(p, "part_kind", "") == "tool-call"
+                            )
                             logger.warning(
-                                f"Agent attempted premature completion with {sum(1 for p in node.model_response.parts if getattr(p, 'part_kind', '') == 'tool-call')} pending tools"
+                                f"Agent attempted premature completion with {pending_tools_count} "
+                                f"pending tools"
                             )
                         else:
                             # Check if content suggests pending actions
@@ -131,7 +132,8 @@ async def _process_node(
                                 phrase in combined_text for phrase in pending_phrases
                             )
 
-                            # Also check for action verbs at end of content suggesting incomplete action
+                            # Also check for action verbs at end of content
+                            # suggesting incomplete action
                             action_endings = [
                                 "checking",
                                 "searching",
@@ -150,21 +152,30 @@ async def _process_node(
                                 # Too early to complete with pending intentions
                                 if state_manager.session.show_thoughts:
                                     await ui.warning(
-                                        "⚠️ SUSPICIOUS COMPLETION - Stated intentions but completing early"
+                                        "⚠️ SUSPICIOUS COMPLETION - "
+                                        "Stated intentions but completing early"
                                     )
                                     found_phrases = [
                                         p for p in pending_phrases if p in combined_text
                                     ]
-                                    await ui.muted(
-                                        f"   Iteration {state_manager.session.iteration_count} with pending: {found_phrases}"
+                                    iteration_msg = (
+                                        f"   Iteration {state_manager.session.iteration_count} "
+                                        f"with pending: {found_phrases}"
                                     )
+                                    await ui.muted(iteration_msg)
                                     if ends_with_action:
+                                        action_verb = (
+                                            combined_text.split()[-1]
+                                            if combined_text.split()
+                                            else ""
+                                        )
                                         await ui.muted(
-                                            f"   Content ends with action verb: '{combined_text.split()[-1] if combined_text.split() else ''}'"
+                                            f"   Content ends with action verb: '{action_verb}'"
                                         )
                                 # Still allow it but log warning
                                 logger.warning(
-                                    f"Task completion with pending intentions detected: {found_phrases}"
+                                    f"Task completion with pending intentions detected: "
+                                    f"{found_phrases}"
                                 )
 
                             # Normal completion - transition to RESPONSE state and mark completion
@@ -184,7 +195,8 @@ async def _process_node(
                 combined_content = " ".join(all_content_parts).strip()
                 appears_truncated = check_for_truncation(combined_content)
 
-            # If we only got empty content and no tool calls, we should NOT consider this a valid response
+            # If we only got empty content and no tool calls, we should NOT consider this
+            # a valid response
             # This prevents the agent from stopping when it gets empty responses
             if not has_non_empty_content and not any(
                 hasattr(part, "part_kind") and part.part_kind == "tool-call"
@@ -206,17 +218,6 @@ async def _process_node(
                     await ui.muted("⚠️ TRUNCATED RESPONSE DETECTED - CONTINUING")
                     await ui.muted(f"   Last content: ...{combined_content[-100:]}")
 
-        # Stream content to callback if provided
-        # Use this as fallback when true token streaming is not available
-        if streaming_callback and not STREAMING_AVAILABLE:
-            for part in node.model_response.parts:
-                if hasattr(part, "content") and isinstance(part.content, str):
-                    content = part.content.strip()
-                    if content and not content.startswith('{"thought"'):
-                        # Stream non-JSON content (actual response content)
-                        if streaming_callback:
-                            await streaming_callback(content)
-
         # Enhanced display when thoughts are enabled
         if state_manager.session.show_thoughts:
             await _display_raw_api_response(node, ui)
@@ -312,14 +313,27 @@ async def _process_tool_calls(
     tool_buffer: Optional[ToolBuffer],
     response_state: Optional[ResponseState],
 ) -> None:
-    """Process tool calls from the node."""
+    """
+    Process tool calls from the node using smart batching strategy.
+
+    Smart batching optimization:
+    - Collect all read-only tools into a single batch (regardless of write tools in between)
+    - Execute all read-only tools in one parallel batch
+    - Execute write/execute tools sequentially in their original order
+
+    This maximizes parallel execution efficiency by avoiding premature buffer flushes.
+    """
     from tunacode.constants import READ_ONLY_TOOLS
     from tunacode.ui import console as ui
 
     # Track if we're processing tool calls
     is_processing_tools = False
 
-    # Process tool calls
+    # Phase 1: Collect and categorize all tools
+    read_only_tasks = []
+    research_agent_tasks = []
+    write_execute_tasks = []
+
     for part in node.model_response.parts:
         if hasattr(part, "part_kind") and part.part_kind == "tool-call":
             is_processing_tools = True
@@ -328,127 +342,191 @@ async def _process_tool_calls(
                 response_state.transition_to(AgentState.TOOL_EXECUTION)
                 if state_manager.session.show_thoughts:
                     await ui.muted("STATE → TOOL_EXECUTION (executing tools)")
+
             if tool_callback:
-                # Check if this is a read-only tool that can be batched
-                if tool_buffer is not None and part.tool_name in READ_ONLY_TOOLS:
-                    # Add to buffer instead of executing immediately
-                    tool_buffer.add(part, node)
-
-                    # Update spinner to show we're collecting tools
-                    buffered_count = len(tool_buffer.read_only_tasks)
-                    await ui.update_spinner_message(
-                        f"[bold #00d7ff]Collecting tools ({buffered_count} buffered)...[/bold #00d7ff]",
-                        state_manager,
-                    )
-
+                # Categorize: research agent vs read-only vs write/execute
+                if part.tool_name == "research_codebase":
+                    research_agent_tasks.append((part, node))
                     if state_manager.session.show_thoughts:
                         await ui.muted(
-                            f"⏸️ BUFFERED: {part.tool_name} (will execute in parallel batch)"
+                            f"COLLECTED: {part.tool_name} (research agent - special display)"
+                        )
+                elif part.tool_name in READ_ONLY_TOOLS:
+                    read_only_tasks.append((part, node))
+                    if state_manager.session.show_thoughts:
+                        await ui.muted(
+                            f"COLLECTED: {part.tool_name} (will execute in parallel batch)"
                         )
                 else:
-                    # Write/execute tool - process any buffered reads first
-                    if tool_buffer is not None and tool_buffer.has_tasks():
-                        import time
-
-                        from .tool_executor import execute_tools_parallel
-
-                        buffered_tasks = tool_buffer.flush()
-                        batch_id = getattr(state_manager.session, "batch_counter", 0) + 1
-                        state_manager.session.batch_counter = batch_id
-
-                        start_time = time.time()
-
-                        # Update spinner message for batch execution
-                        tool_names = [part.tool_name for part, _ in buffered_tasks]
-                        batch_msg = get_batch_description(len(buffered_tasks), tool_names)
-                        await ui.update_spinner_message(
-                            f"[bold #00d7ff]{batch_msg}...[/bold #00d7ff]", state_manager
-                        )
-
-                        # Enhanced visual feedback for parallel execution (suppress in plan mode)
-                        if not state_manager.is_plan_mode():
-                            await ui.muted("\n" + "=" * 60)
-                            await ui.muted(
-                                f"🚀 PARALLEL BATCH #{batch_id}: Executing {len(buffered_tasks)} read-only tools concurrently"
-                            )
-                            await ui.muted("=" * 60)
-
-                            # Display details of what's being executed
-                            for idx, (buffered_part, _) in enumerate(buffered_tasks, 1):
-                                tool_desc = f"  [{idx}] {buffered_part.tool_name}"
-                                if hasattr(buffered_part, "args") and isinstance(
-                                    buffered_part.args, dict
-                                ):
-                                    if (
-                                        buffered_part.tool_name == "read_file"
-                                        and "file_path" in buffered_part.args
-                                    ):
-                                        tool_desc += f" → {buffered_part.args['file_path']}"
-                                    elif (
-                                        buffered_part.tool_name == "grep"
-                                        and "pattern" in buffered_part.args
-                                    ):
-                                        tool_desc += (
-                                            f" → pattern: '{buffered_part.args['pattern']}'"
-                                        )
-                                        if "include_files" in buffered_part.args:
-                                            tool_desc += (
-                                                f", files: '{buffered_part.args['include_files']}'"
-                                            )
-                                    elif (
-                                        buffered_part.tool_name == "list_dir"
-                                        and "directory" in buffered_part.args
-                                    ):
-                                        tool_desc += f" → {buffered_part.args['directory']}"
-                                    elif (
-                                        buffered_part.tool_name == "glob"
-                                        and "pattern" in buffered_part.args
-                                    ):
-                                        tool_desc += (
-                                            f" → pattern: '{buffered_part.args['pattern']}'"
-                                        )
-                                await ui.muted(tool_desc)
-                            await ui.muted("=" * 60)
-
-                        await execute_tools_parallel(buffered_tasks, tool_callback)
-
-                        elapsed_time = (time.time() - start_time) * 1000
-                        sequential_estimate = (
-                            len(buffered_tasks) * 100
-                        )  # Assume 100ms per tool average
-                        speedup = sequential_estimate / elapsed_time if elapsed_time > 0 else 1.0
-
-                        if not state_manager.is_plan_mode():
-                            await ui.muted(
-                                f"✅ Parallel batch completed in {elapsed_time:.0f}ms "
-                                f"(~{speedup:.1f}x faster than sequential)\n"
-                            )
-
-                        # Reset spinner message back to thinking
-                        from tunacode.constants import UI_THINKING_MESSAGE
-
-                        await ui.update_spinner_message(UI_THINKING_MESSAGE, state_manager)
-
-                    # Now execute the write/execute tool
+                    write_execute_tasks.append((part, node))
                     if state_manager.session.show_thoughts:
-                        await ui.warning(f"⚠️ SEQUENTIAL: {part.tool_name} (write/execute tool)")
+                        await ui.muted(f"COLLECTED: {part.tool_name} (will execute sequentially)")
 
-                    # Update spinner for sequential tool
-                    tool_args = getattr(part, "args", {}) if hasattr(part, "args") else {}
-                    # Parse args if they're a JSON string
-                    if isinstance(tool_args, str):
-                        import json
+    # Phase 2: Execute research agent with special UI display
+    if research_agent_tasks and tool_callback:
+        from tunacode.ui import console as ui
 
-                        try:
-                            tool_args = json.loads(tool_args)
-                        except (json.JSONDecodeError, TypeError):
-                            tool_args = {}
-                    tool_desc = get_tool_description(part.tool_name, tool_args)
-                    await ui.update_spinner_message(
-                        f"[bold #00d7ff]{tool_desc}...[/bold #00d7ff]", state_manager
+        from .tool_executor import execute_tools_parallel
+
+        # Display research agent panel with query details
+        for part, _ in research_agent_tasks:
+            tool_args = getattr(part, "args", {}) if hasattr(part, "args") else {}
+            # Parse args if they're a JSON string
+            if isinstance(tool_args, str):
+                import json
+
+                try:
+                    tool_args = json.loads(tool_args)
+                except (json.JSONDecodeError, TypeError):
+                    tool_args = {}
+
+            # Build research agent panel content
+            query = tool_args.get("query", "Unknown query")
+            directories = tool_args.get("directories", ["."])
+            max_files = tool_args.get("max_files", 3)
+
+            # Format panel text (batch-style format)
+            dirs_str = ", ".join(directories) if isinstance(directories, list) else str(directories)
+            panel_text = f"""**RESEARCH AGENT**: {query}
+
+**Directories:** {dirs_str} | **Max files:** {max_files}
+
+**Tools available:** grep, read_file, list_dir, glob (read-only)"""
+
+            # Display purple research agent panel
+            await ui.research_agent(panel_text)
+
+            # Update spinner to show research in progress
+            query_preview = query[:60] + "..." if len(query) > 60 else query
+            await ui.update_spinner_message(
+                f"[bold {colors.accent}]Researching: {query_preview}[/bold {colors.accent}]",
+                state_manager,
+            )
+
+        # Execute the research agent tool
+        results = await execute_tools_parallel(research_agent_tasks, tool_callback)
+
+        # Show completion summary if results available
+        if results and len(results) > 0:
+            result = results[0]  # Research agent typically returns single result
+            if isinstance(result, dict) and not result.get("error"):
+                files = result.get("relevant_files", [])
+                findings_count = len(result.get("key_findings", []))
+                if files:
+                    summary = (
+                        f"[bold {colors.accent}]Research complete: analyzed {len(files)} file(s), "
+                        f"{findings_count} finding(s)[/bold {colors.accent}]"
                     )
+                    await ui.update_spinner_message(summary, state_manager)
+                    # Brief pause to show summary before resetting
+                    import asyncio
 
-                    await tool_callback(part, node)
+                    await asyncio.sleep(0.5)
+
+        # Reset spinner message back to thinking
+        from tunacode.constants import UI_THINKING_MESSAGE
+
+        await ui.update_spinner_message(UI_THINKING_MESSAGE, state_manager)
+
+    # Phase 3: Execute read-only tools in ONE parallel batch
+    if read_only_tasks and tool_callback:
+        from .tool_executor import execute_tools_parallel
+
+        batch_id = getattr(state_manager.session, "batch_counter", 0) + 1
+        state_manager.session.batch_counter = batch_id
+
+        # Update spinner to show batch collection
+        collection_msg = (
+            f"[bold {colors.primary}]Collected {len(read_only_tasks)} "
+            f"read-only tools...[/bold {colors.primary}]"
+        )
+        await ui.update_spinner_message(collection_msg, state_manager)
+
+        # Update spinner message for batch execution
+        tool_names = [part.tool_name for part, _ in read_only_tasks]
+        batch_msg = get_batch_description(len(read_only_tasks), tool_names)
+        await ui.update_spinner_message(
+            f"[bold {colors.primary}]{batch_msg}...[/bold {colors.primary}]", state_manager
+        )
+
+        # Build batch content as markdown for Rich panel
+        batch_content = (
+            f"**PARALLEL BATCH #{batch_id}**: "
+            f"Executing {len(read_only_tasks)} read-only tools concurrently\n\n"
+        )
+
+        # Display details of what's being executed
+        from .agent_helpers import get_readable_tool_description
+
+        for idx, (part, _) in enumerate(read_only_tasks, 1):
+            tool_args = getattr(part, "args", {}) if hasattr(part, "args") else {}
+            # Parse args if they're a JSON string
+            if isinstance(tool_args, str):
+                import json
+
+                try:
+                    tool_args = json.loads(tool_args)
+                except (json.JSONDecodeError, TypeError):
+                    tool_args = {}
+            readable_desc = get_readable_tool_description(part.tool_name, tool_args)
+            tool_desc = f"  **[{idx}]** {readable_desc}"
+            batch_content += f"{tool_desc}\n"
+
+        await execute_tools_parallel(read_only_tasks, tool_callback)
+
+        # Display batch execution in green Rich panel
+        await ui.batch(batch_content)
+
+        # Reset spinner message back to thinking
+        from tunacode.constants import UI_THINKING_MESSAGE
+
+        await ui.update_spinner_message(UI_THINKING_MESSAGE, state_manager)
+
+    # Phase 4: Execute write/execute tools sequentially
+    for part, node in write_execute_tasks:
+        if state_manager.session.show_thoughts:
+            await ui.warning(f"⚠️ SEQUENTIAL: {part.tool_name} (write/execute tool)")
+
+        # Update spinner for sequential tool
+        tool_args = getattr(part, "args", {}) if hasattr(part, "args") else {}
+        # Parse args if they're a JSON string
+        if isinstance(tool_args, str):
+            import json
+
+            try:
+                tool_args = json.loads(tool_args)
+            except (json.JSONDecodeError, TypeError):
+                tool_args = {}
+        tool_desc = get_tool_description(part.tool_name, tool_args)
+        await ui.update_spinner_message(
+            f"[bold {colors.primary}]{tool_desc}...[/bold {colors.primary}]", state_manager
+        )
+
+        # Execute the tool with robust error handling
+        try:
+            await tool_callback(part, node)
+        except UserAbortError:
+            raise
+        except Exception as tool_err:
+            logger.error(
+                "Tool callback failed: tool=%s iter=%s err=%s",
+                getattr(part, "tool_name", "<unknown>"),
+                getattr(state_manager.session, "current_iteration", "?"),
+                tool_err,
+                exc_info=True,
+            )
+            # Surface to UI when thoughts are enabled, then continue gracefully
+            if getattr(state_manager.session, "show_thoughts", False):
+                await ui.warning(
+                    f"❌ Tool failed: {getattr(part, 'tool_name', '<unknown>')} — continuing"
+                )
+        finally:
+            # Tool execution completed - resource cleanup handled by BaseTool.execute()
+            tool_name = getattr(part, "tool_name", "<unknown>")
+            logger.debug(
+                "Tool execution completed (success or failure): tool=%s",
+                tool_name,
+            )
 
     # Track tool calls in session
     if is_processing_tools:
