@@ -3,6 +3,11 @@
 import re
 from typing import Tuple
 
+_COMPLETION_MARKERS = (
+    re.compile(r"^\s*TUNACODE\s+DONE:\s*", re.IGNORECASE),
+    re.compile(r"^\s*TUNACODE[_\s]+TASK_COMPLETE\s*:?[\s]*", re.IGNORECASE),
+)
+
 
 def check_task_completion(content: str) -> Tuple[bool, str]:
     """
@@ -21,12 +26,16 @@ def check_task_completion(content: str) -> Tuple[bool, str]:
 
     lines = content.split("\n")
 
-    # New marker: any line starting with "TUNACODE DONE:" (case-insensitive, allow leading whitespace)
-    done_pattern = re.compile(r"^\s*TUNACODE\s+DONE:\s*", re.IGNORECASE)
     for idx, line in enumerate(lines):
-        if done_pattern.match(line):
-            # Remove the marker line and return remaining content
-            cleaned = "\n".join(lines[:idx] + lines[idx + 1 :]).strip()
-            return True, cleaned
+        for pattern in _COMPLETION_MARKERS:
+            match = pattern.match(line)
+            if match:
+                remainder = line[match.end() :].strip()
+                cleaned_lines = lines[:idx]
+                if remainder:
+                    cleaned_lines.append(remainder)
+                cleaned_lines.extend(lines[idx + 1 :])
+                cleaned = "\n".join(cleaned_lines).strip()
+                return True, cleaned
 
     return False, content
