@@ -3,7 +3,6 @@ from .base import BaseSetup
 from .config_setup import ConfigSetup
 from .coordinator import SetupCoordinator
 from .environment_setup import EnvironmentSetup
-from .git_safety_setup import GitSafetySetup
 from .template_setup import TemplateSetup
 
 __all__ = [
@@ -11,7 +10,6 @@ __all__ = [
     "SetupCoordinator",
     "ConfigSetup",
     "EnvironmentSetup",
-    "GitSafetySetup",
     "AgentSetup",
     "TemplateSetup",
 ]
