@@ -6,7 +6,6 @@ used throughout the TunaCode codebase.
 """
 
 from dataclasses import dataclass, field
-from datetime import datetime
 
 # Plan types will be defined below
 from enum import Enum
@@ -17,39 +16,20 @@ from typing import (
     Callable,
     Dict,
     List,
-    Literal,
     Optional,
     Protocol,
     Tuple,
     Union,
 )
 
-# Try to import pydantic-ai types if available
-try:
-    from pydantic_ai import Agent
-    from pydantic_ai.messages import ModelRequest, ToolReturnPart
+# Import pydantic-ai types (required dependency)
+from pydantic_ai import Agent
+from pydantic_ai.messages import ModelRequest, ToolReturnPart
 
-    PydanticAgent = Agent
-    MessagePart = Union[ToolReturnPart, Any]
-    ModelRequest = ModelRequest  # type: ignore[misc]
-    ModelResponse = Any
-except ImportError:
-    # Fallback if pydantic-ai is not available
-    PydanticAgent = Any
-    MessagePart = Any  # type: ignore[misc]
-    ModelRequest = Any
-    ModelResponse = Any  # type: ignore[misc]
-
-
-@dataclass
-class TodoItem:
-    id: str
-    content: str
-    status: Literal["pending", "in_progress", "completed"]
-    priority: Literal["high", "medium", "low"]
-    created_at: datetime
-    completed_at: Optional[datetime] = None
-    tags: list[str] = field(default_factory=list)
+PydanticAgent = Agent
+MessagePart = Union[ToolReturnPart, Any]
+ModelRequest = ModelRequest  # type: ignore[misc]
+ModelResponse = Any
 
 
 # =============================================================================
@@ -129,6 +109,7 @@ class ToolConfirmationResponse:
     approved: bool
     skip_future: bool = False
     abort: bool = False
+    instructions: str = ""
 
 
 # =============================================================================
@@ -195,20 +176,6 @@ class SimpleResult:
     output: str
 
 
-# =============================================================================
-# Plan Types
-# =============================================================================
-
-
-class PlanPhase(Enum):
-    """Plan Mode phases."""
-
-    PLANNING_RESEARCH = "research"
-    PLANNING_DRAFT = "draft"
-    PLAN_READY = "ready"
-    REVIEW_DECISION = "review"
-
-
 class AgentState(Enum):
     """Agent loop states for enhanced completion detection."""
 
@@ -218,47 +185,6 @@ class AgentState(Enum):
     RESPONSE = "response"  # Handling results, may complete or loop
 
 
-@dataclass
-class PlanDoc:
-    """Structured plan document with all required sections."""
-
-    # Required sections
-    title: str
-    overview: str
-    steps: List[str]
-    files_to_modify: List[str]
-    files_to_create: List[str]
-
-    # Optional but recommended sections
-    risks: List[str] = field(default_factory=list)
-    tests: List[str] = field(default_factory=list)
-    rollback: Optional[str] = None
-    open_questions: List[str] = field(default_factory=list)
-    success_criteria: List[str] = field(default_factory=list)
-    references: List[str] = field(default_factory=list)
-
-    def validate(self) -> Tuple[bool, List[str]]:
-        """
-        Validate the plan document.
-
-        Returns:
-            tuple: (is_valid, list_of_missing_sections)
-        """
-        missing = []
-
-        # Check required fields
-        if not self.title or not self.title.strip():
-            missing.append("title")
-        if not self.overview or not self.overview.strip():
-            missing.append("overview")
-        if not self.steps:
-            missing.append("steps")
-        if not self.files_to_modify and not self.files_to_create:
-            missing.append("files_to_modify or files_to_create")
-
-        return len(missing) == 0, missing
-
-
 # =============================================================================
 # Session and State Types
 # =============================================================================
