@@ -66,10 +66,12 @@ def expand_file_refs(text: str) -> Tuple[str, List[str]]:
             - List of absolute paths of files that were successfully expanded.
 
     Raises:
-        ValueError: If a referenced path does not exist.
+        ValueError: If a referenced path does not exist or if attempting to expand
+                   TunaCode's own source directory.
     """
     import os
     import re
+    from pathlib import Path
 
     from tunacode.constants import (
         ERROR_DIR_TOO_LARGE,
@@ -86,6 +88,21 @@ def expand_file_refs(text: str) -> Tuple[str, List[str]]:
     def replacer(match: re.Match) -> str:
         path_spec = match.group(1)
 
+        # Detect if we're expanding TunaCode's own src/ from TunaCode's repo
+        # This prevents accidentally expanding TunaCode's source instead of user's project
+        if path_spec.startswith("src/") or path_spec.startswith("src/**"):
+            cwd = Path.cwd()
+            tunacode_marker = cwd / "src" / "tunacode" / "__init__.py"
+            if tunacode_marker.exists():
+                raise ValueError(
+                    "Error: TunaCode cannot expand file references when running "
+                    "from its own source directory.\n"
+                    "Please run TunaCode from your project directory, not from "
+                    "the TunaCode repository itself.\n"
+                    f"Current directory: {cwd}\n"
+                    "Expected: Your project's root directory"
+                )
+
         is_recursive = path_spec.endswith("/**")
         is_dir = path_spec.endswith("/")
 
